;;; DO NOT MODIFY THIS FILE
(if (featurep 'vc-cc-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "vc-cc/_pkg.el")

(package-provide 'vc-cc :version 1.16 :type 'regular)

;;;***

;;;### (autoloads (tq-create) "tq" "vc-cc/tq.el")

(autoload 'tq-create "tq" "\
Create and return a transaction queue communicating with PROCESS.
PROCESS should be a subprocess capable of sending and receiving
streams of bytes.  It may be a local process, or it may be connected
to a tcp server on another machine." nil nil)

;;;***

(provide 'vc-cc-autoloads)
